==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/utility/units_and_measurements/measurements/_1682.py <==
"""Density"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_DENSITY = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Density"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Density")
    CastSelf = TypeVar("CastSelf", bound="Density._Cast_Density")


__docformat__ = "restructuredtext en"
__all__ = ("Density",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Density:
    """Special nested class for casting Density to subclasses."""

    __parent__: "Density"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def density(self: "CastSelf") -> "Density":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Density(_1655.MeasurementBase):
    """Density

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DENSITY

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Density":
        """Cast to another type.

        Returns:
            _Cast_Density
        """
        return _Cast_Density(self)

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/utility/units_and_measurements/measurements/_1682.py <==
"""DataSize"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_DATA_SIZE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "DataSize"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="DataSize")
    CastSelf = TypeVar("CastSelf", bound="DataSize._Cast_DataSize")


__docformat__ = "restructuredtext en"
__all__ = ("DataSize",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_DataSize:
    """Special nested class for casting DataSize to subclasses."""

    __parent__: "DataSize"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def data_size(self: "CastSelf") -> "DataSize":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class DataSize(_1657.MeasurementBase):
    """DataSize

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _DATA_SIZE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_DataSize":
        """Cast to another type.

        Returns:
            _Cast_DataSize
        """
        return _Cast_DataSize(self)
